@@ -1,4 +1,4 @@
-from ledger.client import LedgerClient
+from ledger_system.client import LedgerClient
 
 import logging
 
@@ -17,12 +17,10 @@ class Accountant:
 
     def __init__(self, bank_account):
         self.bank_account = bank_account
-        self.ledger = LedgerClient(ledger_host="http://ledger-service-dev-1.local-dev:3000")
+        self.ledger = LedgerClient(ledger_host="http://ledger-service-dev-1.local-dev:3000/")
 
         log.info("---------Initialising-------------")
         log.info("Bank Account Number: ", self.bank_account['account_id'])
-        log.info("Main Account Book: ", self.bank_account['ledger_books']['main_balance'])
-        log.info("Block Account Book: ", self.bank_account['ledger_books']['blocked_balance'])
         log.info("Cash Book: ", self.DEFAULT_CASH_BOOK_ID)
 
     def get_book_balances(self, currency):
@@ -99,11 +97,11 @@ class Accountant:
         log.info(operation)
         return operation
 
-    def create_book(self):
+    def create_book(account_id):
         log.info("---------New_ledger-------------")
-        block_book_id = self.ledger.create_book(name=f"{self.bank_account['account_id']}_block_book",
+        block_book_id = account_id.ledger.create_book(name=f"{account_id.bank_account['account_id']}_block_book",
                                                 min_balance="-100")
-        main_book_id = self.ledger.create_book(name=f"{self.bank_account['account_id']}_main_book", min_balance="-100")
+        main_book_id = account_id.ledger.create_book(name=f"{account_id.bank_account['account_id']}_main_book", min_balance="-100")
         new_books = {
             'main_balance': {'name': main_book_id['name'],
                              'id': main_book_id['id']},
@@ -112,3 +110,4 @@ class Accountant:
         }
         log.info(new_books)
         return new_books
+
